# -*- coding: iso-8859-1 -*-
"""
    MoinMoin - VoteRecorder Macro

    @copyright: 2008 by Paul Boddie <paul@boddie.org.uk>
    @license: GNU GPL (v2 or later), see COPYING.txt for details.

    This is like the VotingStars macro except that votes are logged for later
    counting, and the current state of the poll is not shown during voting.
"""

from MoinMoin.util import filesys
from MoinMoin import wikiutil
import os

Dependencies = []

def get_vote_pathname(page, name):
    votes_dir = page.getPagePath("poll")
    if not os.path.exists(votes_dir):
        filesys.makeDirs(votes_dir)
    filename = wikiutil.quoteWikinameFS(name)
    return os.path.join(votes_dir, filename)

def save_vote(page, poll_name, username, vote):
    path = get_vote_pathname(page, username)
    f = open(path, "a")
    try:
        f.write(poll_name + "\t" + vote + "\n")
    finally:
        f.close()

def get_votes(page, poll_name, username, vote):
    path = get_vote_pathname(page, username)
    f = open(path)
    try:
        voting = {}
        for line in f.xreadlines():
            line = line.strip()
            if line:
                poll_name, vote = line.split("\t")
                voting[poll_name] = vote
        return voting
    finally:
        f.close()

def execute(macro, args):
    request = macro.request
    form = macro.form
    fmt = macro.formatter
    page = fmt.page

    output = []

    # Obtain the poll name for presentation purposes.

    args = args.split(",")
    if args:
        poll_name = args[0]
    else:
        output.append(fmt.sysmsg(on=1))
        output.append(fmt.text("Please specify a poll name!"))
        output.append(fmt.sysmsg(on=0))
        return ''.join(output)

    # Show a message if the user is not logged in.

    # Get the user, if known.

    if not request.user.valid:
        output.append(fmt.emphasis(on=1))
        output.append(fmt.text("Please log in to vote!"))
        output.append(fmt.emphasis(on=0))
        return ''.join(output)

    username = request.user.name

    # Handle any vote.

    if form and form.has_key("vote") and form.has_key("poll"):
        poll = form["poll"][0]
        if poll == poll_name:
            save_vote(page, poll, username, form["vote"][0])
            output.append(fmt.emphasis(on=1))
            output.append(fmt.text("Vote submitted!"))
            output.append(fmt.emphasis(on=0))
            return ''.join(output)

    # Show the choices.

    values = {
        "poll" : poll_name, "url" : page.url(request),
        "on_image" : '/wiki/modern/img/star_on.png',
        "off_image" : '/wiki/modern/img/star_off.png'
        }
    choices = range(1, 6)

    output.append(fmt.rawHTML('<form method="get" name="%(poll)s" action="%(url)s#%(poll)s">' % values))
    output.append(fmt.rawHTML('<input type="hidden" name="poll" value="%(poll)s">' % values))
    for choice in choices:
        values["choice"] = choice
        output.append(
            fmt.rawHTML('''
<input type="image" name="vote" value="%(choice)s" src="%(off_image)s"
    onmouseover="this.src='%(on_image)s'"
    onmouseout="this.src='%(off_image)s'">
                ''' % values))
    output.append(fmt.rawHTML('</form>'))

    return ''.join(output)

# vim: tabstop=4 expandtab shiftwidth=4
